aboutsummaryrefslogtreecommitdiff
path: root/bpkg/rep-remove.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2018-04-27 15:53:00 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2018-04-27 15:55:18 +0300
commita2b084651909929d58f6b4bc0f3c742d87ee31f6 (patch)
tree63ef970e6edc44473ca9450dce93cbd130127d57 /bpkg/rep-remove.hxx
parentf86216071cd4d8d120a8afb83f4b452ef7892ea1 (diff)
Add support for repository fragments
Diffstat (limited to 'bpkg/rep-remove.hxx')
-rw-r--r--bpkg/rep-remove.hxx17
1 files changed, 13 insertions, 4 deletions
diff --git a/bpkg/rep-remove.hxx b/bpkg/rep-remove.hxx
index 68d8a36..477f308 100644
--- a/bpkg/rep-remove.hxx
+++ b/bpkg/rep-remove.hxx
@@ -17,13 +17,22 @@ namespace bpkg
rep_remove (const rep_remove_options&, cli::scanner& args);
// Remove a repository if it is not reachable from the root (and thus is not
- // required by any user-added repository).
+ // required by any user-added repository), also removing its unused
+ // repository fragments.
//
void
rep_remove (const dir_path& conf,
transaction&,
const shared_ptr<repository>&);
+ // Remove a repository fragment if it is not referenced by any repository,
+ // also removing its unreachable complements and prerequisites.
+ //
+ void
+ rep_remove_fragment (const dir_path& conf,
+ transaction&,
+ const shared_ptr<repository_fragment>&);
+
// Bring the configuration to the clean state as if repositories were added
// but never fetched. Leave selected packages intact.
//
@@ -45,11 +54,11 @@ namespace bpkg
database&,
bool quiet = true);
// Remove a repository from locations of the available packages it
// contains. Remove packages that come from only this repository.
//
void
- rep_remove_package_locations (transaction&, const string& repository_name);
+ rep_remove_package_locations (transaction&, const string& fragment_name);
}
#endif // BPKG_REP_REMOVE_HXX
@@ -45,11 +54,11 @@ namespace bpkg
database&,
bool quiet = true);
- // Remove a repository from locations of the available packages it
- // contains. Remove packages that come from only this repository.
+ // Remove a repository fragment from locations of the available packages it
+ // contains. Remove packages that come from only this repository fragment.
//
void